@@ -8,14 +8,9 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package MooseX::AttributeShortcuts;
-BEGIN {
-  $MooseX::AttributeShortcuts::AUTHORITY = 'cpan:RSRCHBOY';
-}
-{
-  $MooseX::AttributeShortcuts::VERSION = '0.020_01';
-}
-# git description: 0.020-2-g80a8db2
-
+our $AUTHORITY = 'cpan:RSRCHBOY';
+# git description: 0.027-9-g78dcc28
+$MooseX::AttributeShortcuts::VERSION = '0.027_01';
 
 # ABSTRACT: Shorthand for common attribute options
 
@@ -26,26 +21,31 @@ use namespace::autoclean;
 
 use Moose ();
 use Moose::Exporter;
+use Moose::Meta::TypeConstraint;
 use Moose::Util::MetaRole;
 use Moose::Util::TypeConstraints;
 
 {
     package MooseX::AttributeShortcuts::Trait::Attribute;
-BEGIN {
-  $MooseX::AttributeShortcuts::Trait::Attribute::AUTHORITY = 'cpan:RSRCHBOY';
-}
-{
-  $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.020_01';
-}
-# git description: 0.020-2-g80a8db2
-
+our $AUTHORITY = 'cpan:RSRCHBOY';
+# git description: 0.027-9-g78dcc28
+$MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.027_01';
     use namespace::autoclean;
     use MooseX::Role::Parameterized;
-    use Moose::Util::TypeConstraints qw{ class_type role_type enum };
+    use Moose::Util::TypeConstraints  ':all';
     use MooseX::Types::Moose          ':all';
     use MooseX::Types::Common::String ':all';
 
-    sub _find_or_create_isa_type_constraint { goto \&Moose::Util::TypeConstraints::find_or_create_isa_type_constraint }
+    use aliased 'MooseX::Meta::TypeConstraint::Mooish' => 'MooishTC';
+
+    use List::AllUtils 'any';
+
+    use Package::DeprecationManager -deprecations => {
+        'undocumented-isa-constraints' => '0.23',
+        'hashref-given-to-coerce'      => '0.24',
+    };
+
+    sub _acquire_isa_tc { goto \&Moose::Util::TypeConstraints::find_or_create_isa_type_constraint }
 
     parameter writer_prefix  => (isa => NonEmptySimpleStr, default => '_set_');
     parameter builder_prefix => (isa => NonEmptySimpleStr, default => '_build_');
@@ -60,16 +60,6 @@ BEGIN {
     role {
         my $p = shift @_;
 
-        with 'MooseX::CoercePerAttribute' => { -version  => '1.000' };
-
-        {
-            # XXX: This is evil, and completely temporary until we get full
-            # per-attribute coercion properly integrated with MXAS.
-            my $warn_handler;
-            before _process_coerce_option => sub { $warn_handler  = $SIG{__WARN__}; $SIG{__WARN__} = sub {} };
-            after  _process_coerce_option => sub { $SIG{__WARN__} = $warn_handler                           };
-        }
-
         my $wprefix = $p->writer_prefix;
         my $bprefix = $p->builder_prefix;
         my %prefix = (
@@ -109,77 +99,25 @@ BEGIN {
             my $_opt = sub { $_has->(@_) ? $options->{$_[0]} : q{} };
             my $_ref = sub { ref $_opt->(@_) || q{}                };
 
-            if ($options->{is}) {
+            # handle: is => ...
+            $class->_mxas_is_rwp($name, $options, $_has, $_opt, $_ref);
+            $class->_mxas_is_lazy($name, $options, $_has, $_opt, $_ref);
 
-                if ($options->{is} eq 'rwp') {
+            # handle: builder => 1, builder => sub { ... }
+            $class->_mxas_builder($name, $options, $_has, $_opt, $_ref);
 
-                    $options->{is}     = 'ro';
-                    $options->{writer} = "$wprefix$name";
-                }
+            # handle: isa_class, isa_role, isa_enum
+            $class->_mxas_isa_naughty($name, $options, $_has, $_opt, $_ref);
 
-                if ($options->{is} eq 'lazy') {
+            # handle: isa_instance_of => ...
+            $class->_mxas_isa_instance_of($name, $options, $_has, $_opt, $_ref);
+            # handle: isa => sub { ... }
+            $class->_mxas_isa_mooish($name, $options, $_has, $_opt, $_ref);
 
-                    $options->{is}       = 'ro';
-                    $options->{lazy}     = 1;
-                    $options->{builder}  = 1
-                        unless $_has->('builder') || $_has->('default');
-                }
-            }
+            # handle: constraint => ...
+            $class->_mxas_constraint($name, $options, $_has, $_opt, $_ref);
+            $class->_mxas_coerce($name, $options, $_has, $_opt, $_ref);
 
-            # TODO isa_class - anon class_type generation
-            # TODO isa_role  - anon role_type generation
-            # TODO isa_enum  - anon enum generation
-            # TODO coerce_via - anon coercion (type -> anon subtype+coercion
-
-            # XXX we also ignore conflicts here -- last in wins
-            #confess q{conflict 'isa' and 'isa_class' or 'isa_role'}
-                #if $_has->('isa')
-
-            # XXX undocumented -- not sure this is a great idea
-            $options->{isa} = class_type(delete $options->{isa_class})
-                if $_has->('isa_class');
-            $options->{isa} = role_type(delete $options->{isa_role})
-                if $_has->('isa_role');
-            $options->{isa} = enum(delete $options->{isa_enum})
-                if $_has->('isa_enum');
-
-            ### the pretty business of on-the-fly subtyping...
-            if ($_has->('constraint')) {
-
-                # check for errors...
-                $class->throw_error('You must specify an "isa" when declaring a "constraint"')
-                    if !$_has->('isa');
-                $class->throw_error('"constraint" must be a CODE reference')
-                    if $_ref->('constraint') ne 'CODE';
-
-                # constraint checking! XXX message, etc?
-                push my @opts, constraint => $_opt->('constraint')
-                    if $_ref->('constraint') eq 'CODE';
-
-                # stash our original option away and construct our new one
-                my $isa = $options->{original_isa} = $_opt->('isa');
-                my $isa_tc = _find_or_create_isa_type_constraint($isa);
-                my $new_tc = $isa_tc->create_child_type(@opts);
-
-                if ($isa_tc->has_coercion && $_opt->('coerce') eq "1") {
-
-                    # create our coercion as a copy of the parent
-                    $new_tc->coercion(Moose::Meta::TypeCoercion->new(
-                        type_constraint   => $new_tc,
-                        type_coercion_map => $isa_tc->coercion->type_coercion_map,
-                    ));
-                }
-
-                # fin constraint mucking....
-                $options->{isa} = $new_tc;
-            }
-
-            if ($options->{lazy_build} && $options->{lazy_build} eq 'private') {
-
-                $options->{lazy_build} = 1;
-                $options->{clearer}    = "_clear_$name";
-                $options->{predicate}  = "_has_$name";
-            }
 
             my $is_private = sub { $name =~ /^_/ ? $_[0] : $_[1] };
             my $default_for = sub {
@@ -197,19 +135,6 @@ BEGIN {
                 return;
             };
 
-            # XXX install builder here if a coderef
-            if (defined $options->{builder}) {
-
-                #if (ref $_opt->('builder') eq 'CODE') {
-                if ((ref $options->{builder} || q{}) eq 'CODE') {
-
-                    $options->{_anon_builder} = $options->{builder};
-                    $options->{builder}       = 1;
-                }
-
-                $options->{builder} = "$bprefix$name"
-                    if $options->{builder} eq '1';
-            }
             ### set our other defaults, if requested...
             $default_for->($_) for qw{ predicate clearer };
             my $trigger = "$prefix{trigger}$name";
@@ -239,6 +164,203 @@ BEGIN {
             return $self->$orig($name, %options);
         };
 
+        # handle: is => 'rwp'
+        method _mxas_is_rwp => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless $_opt->('is') eq 'rwp';
+
+            $options->{is}     = 'ro';
+            $options->{writer} = "$wprefix$name";
+
+            return;
+        };
+
+        # handle: is => 'lazy'
+        method _mxas_is_lazy => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless $_opt->('is') eq 'lazy';
+
+            $options->{is}       = 'ro';
+            $options->{lazy}     = 1;
+            $options->{builder}  = 1
+                unless $_has->('builder') || $_has->('default');
+
+            return;
+        };
+
+        # handle: lazy_build => 'private'
+        method _mxas_lazy_build_private => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless $_opt->('lazy_build') eq 'private';
+
+            $options->{lazy_build} = 1;
+            $options->{clearer}    = "_clear_$name";
+            $options->{predicate}  = "_has_$name";
+
+            return;
+        };
+
+        # handle: isa_class, isa_role, isa_enum
+        method _mxas_isa_naughty => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless
+                any { exists $options->{$_} } qw{ isa_class isa_role isa_enum };
+
+            # (more than) fair warning...
+            deprecated(
+                feature => 'undocumented-isa-constraints',
+                message => 'Naughty! isa_class, isa_role, and isa_enum will be removed on or after 01 July 2015!',
+            );
+
+            # XXX undocumented -- not sure this is a great idea
+            $options->{isa} = class_type(delete $options->{isa_class})
+                if $_has->('isa_class');
+            $options->{isa} = role_type(delete $options->{isa_role})
+                if $_has->('isa_role');
+            $options->{isa} = enum(delete $options->{isa_enum})
+                if $_has->('isa_enum');
+
+            return;
+        };
+
+        # handle: builder => 1, builder => sub { ... }
+        method _mxas_builder => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless $_has->('builder');
+
+            if ($_ref->('builder') eq 'CODE') {
+
+                $options->{_anon_builder} = $options->{builder};
+                $options->{builder}       = 1;
+            }
+
+            $options->{builder} = "$bprefix$name"
+                if $options->{builder} eq '1';
+
+            return;
+        };
+
+        method _mxas_isa_mooish => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless $_ref->('isa') eq 'CODE';
+
+            ### build a mooish type constraint...
+            $options->{original_isa} = $options->{isa};
+            $options->{isa} = MooishTC->new(constraint => $options->{isa});
+
+            return;
+        };
+
+        # handle: isa_instance_of => ...
+        method _mxas_isa_instance_of => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless $_has->('isa_instance_of');
+
+            if ($_has->('isa')) {
+
+                $class->throw_error(
+                    q{Cannot use 'isa_instance_of' and 'isa' together for attribute }
+                    . $_opt->('definition_context')->{package} . '::' . $name
+                );
+            }
+
+            $options->{isa} = class_type(delete $options->{isa_instance_of});
+
+            return;
+        };
+
+        method _mxas_constraint => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            return unless $_has->('constraint');
+
+            # check for errors...
+            $class->throw_error('You must specify an "isa" when declaring a "constraint"')
+                if !$_has->('isa');
+            $class->throw_error('"constraint" must be a CODE reference')
+                if $_ref->('constraint') ne 'CODE';
+
+            # constraint checking! XXX message, etc?
+            push my @opts, constraint => $_opt->('constraint')
+                if $_ref->('constraint') eq 'CODE';
+
+            # stash our original option away and construct our new one
+            my $isa         = $options->{original_isa} = $_opt->('isa');
+            $options->{isa} = _acquire_isa_tc($isa)->create_child_type(@opts);
+
+            return;
+        };
+
+        method _mxas_coerce => sub {
+            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
+
+            # "fix" the case of the hashref....  *sigh*
+            if ($_ref->('coerce') eq 'HASH') {
+
+                deprecated(
+                    feature => 'hashref-given-to-coerce',
+                    message => 'Passing a hashref to coerce is unsafe, and will be removed on or after 01 Jan 2015',
+                );
+
+                $options->{coerce} = [ %{ $options->{coerce} } ];
+            }
+
+            if ($_ref->('coerce') eq 'ARRAY') {
+
+                ### must be type => sub { ... } pairs...
+                my @coercions = @{ $_opt->('coerce') };
+                confess 'You must specify an "isa" when declaring "coercion"'
+                    unless $_has->('isa');
+                confess 'coercion array must be in pairs!'
+                    if @coercions % 2;
+                confess 'must define at least one coercion pair!'
+                    unless @coercions > 0;
+
+                my $our_coercion = Moose::Meta::TypeCoercion->new;
+                my $our_type
+                    = $options->{original_isa}
+                    ? $options->{isa}
+                    : _acquire_isa_tc($_opt->('isa'))->create_child_type
+                    ;
+
+                $our_coercion->add_type_coercions(@coercions);
+                $our_type->coercion($our_coercion);
+
+                $options->{original_isa} ||= $options->{isa};
+                $options->{isa}            = $our_type;
+                $options->{coerce}         = 1;
+
+                return;
+            }
+
+            # If our original constraint has coercions and our created subtype
+            # did not have any (as specified in the 'coerce' option), then
+            # copy the parent's coercions over.
+
+            if ($_has->('original_isa') && $_opt->('coerce') eq '1') {
+
+                my $isa_type = _acquire_isa_tc($_opt->('original_isa'));
+
+                if ($isa_type->has_coercion) {
+
+                    # create our coercion as a copy of the parent
+                    $_opt->('isa')->coercion(Moose::Meta::TypeCoercion->new(
+                        type_constraint   => $_opt->('isa'),
+                        type_coercion_map => [ @{ $isa_type->coercion->type_coercion_map } ],
+                    ));
+                }
+
+            }
+
+            return;
+        };
 
         # we hijack attach_to_class in order to install our anon_builder, if
         # we have one.  Note that we don't go the normal
@@ -253,6 +375,36 @@ BEGIN {
             $class->add_method($self->builder => $self->anon_builder);
             return;
         };
+
+        method mi               => sub { shift->associated_class->get_meta_instance                     };
+        method weaken_value     => sub { $_[0]->mi->weaken_slot_value($_[1] => $_) for $_[0]->slots     };
+        method strengthen_value => sub { $_[0]->mi->strengthen_slot_value($_[1] => $_) for $_[0]->slots };
+
+        # NOTE: remove_delegation() will also automagically remove any custom
+        # accessors we create here
+
+        around _make_delegation_method => sub {
+            my ($orig, $self) = (shift, shift);
+            my ($name, $coderef) = @_;
+
+            ### _make_delegation_method() called with a: ref $coderef
+            return $self->$orig(@_)
+                unless 'CODE' eq ref $coderef;
+
+            # this coderef will be installed as a method on the associated class itself.
+            my $custom_coderef = sub {
+                # aka $self from the class instance's perspective
+                my $associated_class_instance = shift @_;
+
+                # in $coderef, $_ will be the attribute metaclass
+                local $_ = $self;
+                return $associated_class_instance->$coderef(@_);
+            };
+
+            return $self->_process_accessors(custom => { $name => $custom_coderef });
+        };
+
+        return;
     };
 }
 
@@ -290,10 +442,10 @@ sub init_meta {
     die "Class $for_class has no metaclass!"
         unless Class::MOP::class_of($for_class);
 
-    # If we're given paramaters to pass on to construct a role with, we build
+    # If we're given parameters to pass on to construct a role with, we build
     # it out here rather than pass them on and allowing apply_metaroles() to
-    # handle it, as there are Very Loud Warnings about how paramatized roles
-    # are non-cachable when generated on the fly.
+    # handle it, as there are Very Loud Warnings about how parameterized roles
+    # are non-cacheable when generated on the fly.
 
     ### $params
     my $role
@@ -322,9 +474,12 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
-=for :stopwords Chris Weyl GitHub attribute's isa one's rwp SUBTYPING
+=for :stopwords Chris Weyl David Graham Knop Steinbrunner GitHub attribute's isa one's rwp
+SUBTYPING foo
+
+=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
 =head1 NAME
 
@@ -332,7 +487,7 @@ MooseX::AttributeShortcuts - Shorthand for common attribute options
 
 =head1 VERSION
 
-This document describes version 0.020_01 of MooseX::AttributeShortcuts - released August 26, 2013 as part of MooseX-AttributeShortcuts.
+This document describes version 0.027_01 of MooseX::AttributeShortcuts - released March 28, 2015 as part of MooseX-AttributeShortcuts.
 
 =head1 SYNOPSIS
 
@@ -470,6 +625,21 @@ Specifying C<builder =E<gt> 1> will cause the following options to be set:
 
     builder => "_build_$name"
 
+=head2 builder => sub { ... }
+
+Passing a coderef to builder will cause that coderef to be installed in the
+class this attribute is associated with the name you'd expect, and
+C<builder =E<gt> 1> to be set.
+
+e.g., in your class,
+
+    has foo => (is => 'ro', builder => sub { 'bar!' });
+
+...is effectively the same as...
+
+    has foo => (is => 'ro', builder => '_build_foo');
+    sub _build_foo { 'bar!' }
+
 =head2 clearer => 1
 
 Specifying C<clearer =E<gt> 1> will cause the following options to be set:
@@ -512,20 +682,102 @@ For an attribute named "_foo":
 This naming scheme, in which the trigger is always private, is the same as the
 builder naming scheme (just with a different prefix).
 
-=head2 builder => sub { ... }
+=head2 handles => { foo => sub { ... }, ... }
 
-Passing a coderef to builder will cause that coderef to be installed in the
-class this attribute is associated with the name you'd expect, and
-C<builder =E<gt> 1> to be set.
+Creating a delegation with a coderef will now create a new, "custom accessor"
+for the attribute.  These coderefs will be installed and called as methods on
+the associated class (just as readers, writers, and other accessors are), and
+will have the attribute metaclass available in $_.  Anything the accessor
+is called with it will have access to in @_, just as you'd expect of a method.
 
-e.g., in your class,
+e.g., the following example creates an attribute named 'bar' with a standard
+reader accessor named 'bar' and two custom accessors named 'foo' and
+'foo_too'.
 
-    has foo => (is => 'ro', builder => sub { 'bar!' });
+    has bar => (
 
-...is effectively the same as...
+        is      => 'ro',
+        isa     => 'Int',
+        handles => {
 
-    has foo => (is => 'ro', builder => '_build_foo');
-    sub _build_foo { 'bar!' }
+            foo => sub {
+                my $self = shift @_;
+
+                return $_->get_value($self) + 1;
+            },
+
+            foo_too => sub {
+                my $self = shift @_;
+
+                return $self->bar + 1;
+            },
+        },
+    );
+
+...and later,
+
+Note that in this example both foo() and foo_too() do effectively the same
+thing: return the attribute's current value plus 1.  However, foo() accesses
+the attribute value directly through the metaclass, the pros and cons of
+which this author leaves as an exercise for the reader to determine.
+
+You may choose to use the installed accessors to get at the attribute's value,
+or use the direct metaclass access, your choice.
+
+=head1 ANONYMOUS SUBTYPING AND COERCION
+
+    "Abusus non tollit usum."
+
+Note that we create new, anonymous subtypes whenever the constraint or
+coercion options are specified in such a way that the Shortcuts trait (this
+one) is invoked.  It's fully supported to use both constraint and coerce
+options at the same time.
+
+This facility is intended to assist with the creation of one-off type
+constraints and coercions.  It is not possible to deliberately reuse the
+subtypes we create, and if you find yourself using a particular isa /
+constraint / coerce option triplet in more than one place you should really
+think about creating a type that you can reuse.  L<MooseX::Types> provides
+the facilities to easily do this, or even a simple L<constant> definition at
+the package level with an anonymous type stashed away for local use.
+
+=head2 isa => sub { ... }
+
+    has foo => (
+        is  => 'rw',
+        # $_ == $_[0] == the value to be validated
+        isa => sub { die unless $_[0] == 1 },
+    );
+
+    # passes constraint
+    $thing->foo(1);
+
+    # fails constraint
+    $thing->foo(5);
+
+Given a coderef, create a type constraint for the attribute.  This constraint
+will fail if the coderef dies, and pass otherwise.
+
+Astute users will note that this is the same way L<Moo> constraints work; we
+use L<MooseX::Meta::TypeConstraint::Mooish> to implement the constraint.
+
+=head2 isa_instance_of => ...
+
+Given a package name, this option will create an C<isa> type constraint that
+requires the value of the attribute be an instance of the class (or a
+descendant class) given.  That is,
+
+    has foo => (is => 'ro', isa_instance_of => 'SomeThing');
+
+...is effectively the same as:
+
+    use Moose::TypeConstraints 'class_type';
+    has foo => (
+        is  => 'ro',
+        isa => class_type('SomeThing'),
+    );
+
+...but a touch less awkward.
 
 =head2 isa => ..., constraint => sub { ... }
 
@@ -582,20 +834,6 @@ coderefs that will coerce a given type to our type.
         ],
     );
 
-=head1 ANONYMOUS SUBTYPING AND COERCION
-
-Note that we create new, anonymous subtypes whenever the constraint or
-coercion options are specified in such a way that the Shortcuts trait (this
-one) is invoked.  It's fully supported to use both constraint and coerce
-options at the same time.
-
-This facility is intended to assist with the creation of one-off type
-constraints and coercions.  It is not possible to deliberately reuse the
-subtypes we create, and if you find yourself using a particular isa /
-constraint / coerce option triplet in more than one place you should really
-think about creating a type that you can reuse.  L<MooseX::Types> provides
-the facilities to easily do this.
-
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -604,18 +842,14 @@ Please see those modules/websites for more information related to this module.
 
 =item *
 
-L<MooseX::CoercePerAttribute|MooseX::CoercePerAttribute>
-
-=item *
-
 L<MooseX::Types|MooseX::Types>
 
 =back
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/RsrchBoy/moosex-attributeshortcuts>
-and may be cloned from L<git://github.com/RsrchBoy/moosex-attributeshortcuts.git>
+The development version is on github at L<http://https://github.com/RsrchBoy/moosex-attributeshortcuts>
+and may be cloned from L<git://https://github.com/RsrchBoy/moosex-attributeshortcuts.git>
 
 =head1 BUGS
 
@@ -630,6 +864,41 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head2 I'm a material boy in a material world
+
+=begin html
+
+<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
+<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-attributeshortcuts&title=RsrchBoy's%20CPAN%20MooseX-AttributeShortcuts&tags=%22RsrchBoy's%20MooseX-AttributeShortcuts%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
+
+=end html
+
+Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
+rather B<it is simply a very pleasant surprise>. I largely create and release
+works like this because I need them or I find it enjoyable; however, don't let
+that stop you if you feel like it ;)
+
+L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-attributeshortcuts&title=RsrchBoy's%20CPAN%20MooseX-AttributeShortcuts&tags=%22RsrchBoy's%20MooseX-AttributeShortcuts%20in%20the%20CPAN%22>,
+L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+
+=head1 CONTRIBUTORS
+
+=for stopwords David Steinbrunner Graham Knop
+
+=over 4
+
+=item *
+
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2011 by Chris Weyl.
